@@ -165,6 +165,13 @@ proc main {server port} {
         $r get novar2
     } {foobared}
 
+    test {SETNX will overwrite EXPIREing key} {
+        $r set x 10
+        $r expire x 10000
+        $r setnx x 20
+        $r get x
+    } {20}
+
     test {EXISTS} {
         set res {}
         $r set newkey test
@@ -901,6 +908,13 @@ proc main {server port} {
         list [$r msetnx x1 xxx y2 yyy] [$r get x1] [$r get y2]
     } {1 xxx yyy}
 
+    test {MSETNX should remove all the volatile keys even on failure} {
+        $r mset x 1 y 2 z 3
+        $r expire y 10000
+        $r expire z 10000
+        list [$r msetnx x A y B z C] [$r mget x y z]
+    } {0 {1 {} {}}}
+
     test {ZSET basic ZADD and score update} {
         $r zadd ztmp 10 x
         $r zadd ztmp 20 y
